@@ -37,6 +37,10 @@
 --     "varname": "tag",
 --     ...
 --   },
+--   "share": {
+--     "varname": "tag",
+--     ...
+--   },
 --   "script": {
 --     "on|off|run|change": "script",
 --      ...
@@ -387,6 +391,7 @@ function cheat.startplugin()
 					time = time,
 					input_trans = input_trans,
 					input_run = function(list) input_run(cheat, list) end,
+					os = { time = os.time, date = os.date, difftime = os.difftime },
 					table =
 					{ insert = table.insert,
 						  remove = table.remove } }
@@ -481,6 +486,16 @@ function cheat.startplugin()
 				cheat.cheat_env[name] = emu.item(ram.items["0/m_pointer"])
 			end
 		end
+		if cheat.share then
+			for name, tag in pairs(cheat.share) do
+				local share = manager:machine():memory().shares[tag]
+				if not share then
+					cheat_error(cheat, "missing share " .. share)
+					return
+				end
+				cheat.cheat_env[name] = share
+			end
+		end
 		local param = cheat.parameter
 		if not param then
 			return
